@@ -165,7 +165,7 @@ def RetrieveData(Date, args):
             name_reprojected = RC.reproject_MODIS(name_collect, epsg_to)
         
             # Clip the data to the users extend
-            data, geo = RC.clip_data(name_reprojected, latlim, lonlim)
+            data, geo, proj = RC.clip_data(name_reprojected, latlim, lonlim)
                 
             # Save results as Gtiff
             if TimeStep == 8:
@@ -173,7 +173,7 @@ def RetrieveData(Date, args):
             if TimeStep == 1:
                 name_collect_time = os.path.join(output_folder, 'Merged_Time.tif')
                 name_reprojected_time = RC.reproject_MODIS(name_collect_time, epsg_to) 
-                data_time, geo = RC.clip_data(name_reprojected_time, latlim, lonlim)
+                data_time, geo, proj = RC.clip_data(name_reprojected_time, latlim, lonlim)
                 data_time[data_time==25.5] = np.nan
                 data_time_ave = np.nanmean(data_time)
                 try:
@@ -192,7 +192,7 @@ def RetrieveData(Date, args):
                 if angle_info == 1:
                     name_collect_angle = os.path.join(output_folder, 'Merged_Obsang.tif')
                     name_reprojected_angle = RC.reproject_MODIS(name_collect_angle, epsg_to) 
-                    data_angle, geo = RC.clip_data(name_reprojected_angle, latlim, lonlim)
+                    data_angle, geo, proj = RC.clip_data(name_reprojected_angle, latlim, lonlim)
                     data_angle[data_angle==25.5] = np.nan
                     OnsangfileName = os.path.join(output_folder, 'Angle_MYD11A1_degrees_daily_' + Date.strftime('%Y') + '.' + Date.strftime('%m') + '.' + Date.strftime('%d') + '.tif')    
                     data_angle[data_angle==0.] = -9999
